bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 22. Aventiure
___________________________________________________ #### Auentv wie Chriemh' vn– Ezele brvten in der stat ze #### Wienne
| ### <Si> was ze Treysenmvore vnz an den vierden tac ### div molte vof der straze die wile nie gelac ### sine stvbe sam iz brunne allenthalben dan ### da riten durch Osterriche des kunic Ezelen man ### Do waren ovch dem kunige div mære nv geseit ### des im von gedanchen swnden siniv leit ### wie herrenlichen Chriemh' da chome durch div lant ### er begunde vaste gahen da er die minneklichen vant
###### 1365 | ### Von vil maniger sprache sah man vf den wegn ### vor Ezelen riten vil manigenn chvnen degen ### kristen vn– heiden vil ma[52v]nic witiv schar ### da si ir frowen fvnden si fvren vrolichen dar
| ### Von Rvzzen vn– von Chriechen reit da vil manic man ### Polanen vn– Vlachen den sah man ebene gan ### ir pferit vn– ros div gvten da si mit chreftin riten ### swaz si site habeten der wart vil wenich iht vermiten
###### 1367 | ### Von dem lande vz Chyewen reit ovch da manic man ### vn– die wilden Pescenære da wart des vil getan ### mit den bogen schiezen zen vogelen die da flvogen ### ir pfile si vil sere mit chraft vnz an die wende zvogen
###### 1368 | ### Ein stat bi Tvonowe lit in Osterlant ### div ist geheizen Tvlme da wart ir sit bechant ### vil manic site vremde den si nie da vor gesach ### si enpfiengen da genvge den leide sit von ir geschach
| ### Vor Ezele dem richen ein gesinde reit ### vro in hohem mvote hobesch vn– ovch gemeit ### wol vier vn– zweinzech fvrsten rich un– her ### daz si ir frowen sêhen da von negerten si niht mer
###### 1370 | ### Der herzoge Ramunch vzer Vlâchen lant ### mit sibenhundert mannen chom er fvr si gerant ### sam die wilden vogele so sah man si varn ### do chome der fvrste Gibeche mit vil herlichen scharn
###### 1371 | ### Hornboge der snelle wol mit tvsint man ### kerte vonme kunige gein siner frowen dan ### vil lvte wart geschallet nach des landes siten ### von den Hunin magen wart ovch da sere geriten
###### 1372 | ### Do chom von Tenemarche der chvene Hawart ### un– Irinch der starche vor valsche wol bewart ### vn– Irnfrit von Dvringen ein fverste lobesam ### die enpfiengen Chriemh' als ez ir eren wol gezam
###### 1373 | ### mit zwelf hundert mannen die hetens in ir schar ### ovch chom der herre Bloedelin mit tusint helden dar ### der Etzelen brvoder vz der Hunin lant ### der ilte mit den sinen da er die kuniginne vant
| ### Do chom der kunic Ezele vn– ovch herre Dietrich ### mit allen sinen degenen da was vil lobelich ### manic ritter edele biderb vn– gvot ### des wart der chvniginne ein teil gesenftet der mvot
###### 1375 | ### Do sprach von Bechelaren der herre Rvdeger ### frowe ivch wil enpfahen hie der kunic her ### swen ich iv rate chvssen daz sol sin getan ### iane mvgt ir niht geliche grvzen <alle> skuniges man
###### 1376 | ### Do hvp man von dem moere die kuniginne her ### Ezele der riche enbeite ovch do niht mer ### er stvnt von sinem rosse mit manigem chvnen man ### man sah in vroliche gein Chriemh' gen
###### 1377 | ### Zwen fvrsten riche als vns daz ist geseit ### bi der frowen giengen vn– habten ir div kleit ### do ir der kunic Ezele hin begegene gie ### da si den fursten edele mit chusse gvtlich enpfie
###### 1378 | ### Vf rihte si ir geben[53r]de ir varwe wolgetan ### div lvhte ir vzem golde da stvnt vil manic man ### die iahen daz froe Helche niht schoner chunde sin ### da bi stvnt vil nahen des wirtes <brvder> Bloedelin
###### 1379 | ### Den hiez si chussen Rvedeger der marcgrave rich ### vnt den kunic Gibechen da stvnt ovch her Dietrich ### der rechen chuste zwelfe daz Ezelen wip ### do enpfie si svs mit grvoze vil maniges chvnen rechen lip
###### 1380 | ### In der selben wile vn– Ezele bi ir stvont ### do gebarten da die tvmben so noch die lvte tvont ### vil manigen pvneyz langen sah man da geriten ### daz taten kristen degene vn– ovch die heiden nach ir siten
###### 1381 | ### Wie rehte hurteklichen die Dietriches man ### die schefte liezen vliegen mit trvnzvonen dan ### vil hohe vber schilde von gvter ritter hant ### die si da gerne sahen die wrden schiere bechant
###### 1382 | ### Da wart von schefte brechen vil michel chrach vernomen ### do waren von dem lande die rechen alle chomen ### vn– ovch des chuniges geste vil manic edel man ### do gie der kunic riche mit der kuniginne dan
| ### Si sahen bi in stende ein vil herlich gezelt ### von hutten was erfvllet alumbe gar daz velt ### da si vnder solden rvowen nach ir arebeit ### von helden wart gewiset vil manic wætlichiv meit
###### 1384 | ### mit Chriemh' dannen da si sit gesaz ### vf riche gesidele der marcgrave daz ### hete so geschaffen daz man ez vant vil gvot ### do stvnt dem kunige Ezelen harte hohe der mvot
###### 1385 | ### Waz si zesamne redeten daz ist mir vnbechant ### wan zwisschen sinen handen was ir wiziv hant ### si gesazen minnekliche da Rvdeger der degen ### den kunic niht lazen wolde der frowen heinliche pflegen
###### 1386 | ### Do hiez man lan beliben den buhvrt vber al ### mit eren wart verendet da der groze schal ### do giengen zvo den hutten die Ezelen man ### man gab in herberge vil witen allenthalben dan
| ### Den abent zvo der nahte si heten gvot gemach ### vnz man den liehten morgen aber schinen sach ### do was gesatelet Ezelen vn– allen sinen man ### vil maniger chvrcewile man im zen eren da began
###### 1388 | ### Der chunic ez lobeliche die Hunin scaffen bat ### do riten si von Tvlme ze Wiene zv der stat ### da was vil wol gezieret vil maniger frowen lip ### si enpfiengen wol mit eren des kunic Ezelen wip
###### 1389 | ### Mit vil grozem vollen so was in bereit ### swaz si haben solden vil manic helt gemeit ### entrvsten riche sætele die Ezelen man ### sich hvp mit grozen eren des kuniges hochgeciten an
###### 1390 | ### Sine mohten niht beliben ze Wiene in der stat ### die niht geste waren Rvdeger die bat ### von der burege [53v]dannen herbergen in daz lant ### ich wæn man alle cite bi frowen Chriemh' vant
###### 1391 | ### den herren Dietrichen vn– anders manigen degn ### si heten sich der rowe mit arebeite bewegn ### durch daz si den gesten getrosten wol den mvot ### der kunic mit sinen frivnden hete churcewile gvot
###### 1392 | ### Div hochgecite was gevallen an einen pfinxtach ### do der kunic Ezele bi Chriemh' lach ### in der stat ze <Wiene> si wæn so manigen man ### bi ir ersten vriedel nie ze dienste gewan
###### 1393 | ### Si chvnte sich mit gabe dem der si nie gesach ### vil maniger darvnder zvo den gesten sprach ### wir wanden daz frov Chriemh' niht gvetes mohte han ### nv ist hie michel wnder von ir gabe getan
###### 1394 | ### Div hochgecit do werte wol sibenzehn tage ### ob chunic ie deheiner mit warheit oder nach sage ### deheine grozer gewnne daz ist vns gar verdeit ### alle di da waren die trvgen iteniwe chleit
###### 1395 | ### Si wæn in Niderlanden da vor nie gesaz ### mit so manigem rechen da von gelovbe ich daz ### was Sivrit rich des gvotes daz er doch nie gewan ### so manigen rechen edelen als si zen Hunin mohte han
###### 1396 | ### Ovch gab ir nie deheiner zvo sin selbes hochgezit ### so manigen richen mantel lanch <tief> vn– wit ### noch so richer chleider der si vil mohten han ### so si durch Chriemh' alle heten hie getan
| ### Die chunden un– die geste die heten einen mvot ### daz si da niht sparten deheiner slahte gvot ### swes ieman an si gerte daz gaben si bereit ### des stvnt da vil der degene von milte bloz ane chleit
###### 1398 | ### Wie si ze Rine sæze si gedaht an daz ### bi ir vil edelem manne ir ovgen wrden naz ### si hetes vaste hæle deiz iemen chunde sehn ### ir was nach manigem leide so vil der eren hie geschehen
###### 1399 | ### Swaz iemen tet mit milte daz was gar ein wint ### vnz an Dietrichen swaz Botelunges chint ### im gegebn hete daz was gar verswant ### ovch tet da michel wnder des milten Rvdegeres hant
###### 1400 | ### Vzer Vngerlande der fvrste Bloedelin ### der hiez da machen lære vil manigiv leitschrin ### von silber vn– von golde daz wart gar hin gegebn ### man gesach nie kuniges degene so rehte vroliche lebn
###### 1401 | ### Swemmel vn– Wêrbel die Ezelen spileman ### ih wæn ir ieslicher zer hochgecite da gewan ### wol ze tvsint marchen oder dannoch baz ### da div frowe Chriemh' bi Ezelen vnder chronen saz
| ### An dem ahtzehenden morgen von Wiene si do riten ### da wart in ritterschefte schilde vil versniten ### von spern die da fvrten die rechen an der hant ### svs chome der kunic Ezele mit frevden in der Hunin lant
###### 1403 | ### Ze Heimburch der alten si waren vber naht ### done chunde niemen wizzen wol des volches aht [54r] ### mit wie getaner chrefte si riten dvrch daz lant ### hey waz man schoner frowen in ir heymvete vant
###### 1404 | ### Ze Miesenburch der richen da schiften si sich an ### daz wazzer wart verdechet von ross vn– ovch von man ### sam ez erde wære swaz man sin vbersach ### die <wegemveden> frowen heten senfte vn– oech gemach
###### 1405 | ### Zesamne was gebunden manic schif vil gvot ### daz in niht schaden chunde die venden noch div flvot ### dar vber was gespannen vil manic gvot gezelt ### sam ob si noch heten bediv lant vn– velt
| ### Ze Ezelen buorge div mære chomen dan ### do frevten sich dar inne wibe vn– man ### daz Helchen ingesinde des ê div frowe pflach ### gelebte bi Chriemh' sit manigen froelichen tach
###### 1407 | ### Do stvnt in lieber warte vil manic edel meit ### die von Helchen tode heten manigiv leit ### siben chunige tohter Chriemh' noch da vant ### von den was wol gezieret allez Ezelen lant
###### 1408 | ### Div iuncfrowe Herrat noch des gesindes pflac ### div Helchen swester tohter an der vil tugende lac ### div gemahle Dietriches eins richen chuniges chint ### div tohter Næntwines div hete vil der eren sint
###### 1409 | ### Von der geste chunfte so troste sich ir mvot ### ovch was dar zv bereitet vil chreftechlichez gvot ### wer chunde iv daz bescheiden wie sit der kunic saz ### sine gelebten da zen Hunin mit deheiner chvniginne baz
| ### Do der wirt mit sime wibe von dem stade reit ### wer ieslichiv wære daz wart zehant geseit ### der edeln kuniginne si grvztes deste baz ### hey wie gewaltekliche sit an Helchen stat gesaz
###### 1411 | ### Mit triwen hoher dienste wart ir vil bechant ### do teilte div frowe Chriemh' golt vn– ovch gewant ### silber un– gesteine swaz si des vber Rin ### mit ir zen Hvnin brahte daz mvse gar zerteilet sin
###### 1412 | ### Ovch wrden ir mit dienste sider vndertan ### al des chuniges mage vn– alle sine man ### daz nie div frowe Helche so gewaldechlich gebot ### so si nv mvsin dienen vnz an den Chriemh' tot
###### 1413 | ### Do stvnt mit solhen eren der hof vn– oech daz lant ### daz man da zallen ziten die churzewile vant ### swar nach ieslichem daz herce trvch den mvot ### durch des kuniges liebe vn– ovch die kvniginne gvot

<<< Übersicht <<< vorige Seite nächste Seite >>>